.. _vmware_scenarios:

****************************
Ansible for VMware Scenarios
****************************

These scenarios teach you how to accomplish common VMware tasks using Ansible. To get started, please select the task you want to accomplish.

.. toctree::
   :maxdepth: 1

   scenario_clone_template
   scenario_rename_vm
   scenario_remove_vm
   scenario_find_vm_folder
   scenario_vmware_http
   scenario_vmware_tools_connection
